==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/nus-SS.pl <==
{
  am_pm_abbreviated => [
    "RW",
    "T\N{U+014a}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E\N{U+060c} d-M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E\N{U+060c} d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E\N{U+060c} d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "nus-SS",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jiec",
    "R\N{U+025b}w",
    "Di\N{U+0254}\N{U+0331}k",
    "\N{U+014a}uaan",
    "Dhieec",
    "B\N{U+00e4}k\N{U+025b}l",
    "C\N{U+00e4}\N{U+014b}",
  ],
  day_format_narrow => [
    "J",
    "R",
    "D",
    "\N{U+014a}",
    "D",
    "B",
    "C",
  ],
  day_format_wide => [
    "Jiec la\N{U+0331}t",
    "R\N{U+025b}w l\N{U+00e4}tni",
    "Di\N{U+0254}\N{U+0331}k l\N{U+00e4}tni",
    "\N{U+014a}uaan l\N{U+00e4}tni",
    "Dhieec l\N{U+00e4}tni",
    "B\N{U+00e4}k\N{U+025b}l l\N{U+00e4}tni",
    "C\N{U+00e4}\N{U+014b} ku\N{U+0254}th",
  ],
  day_stand_alone_abbreviated => [
    "Jiec",
    "R\N{U+025b}w",
    "Di\N{U+0254}\N{U+0331}k",
    "\N{U+014a}uaan",
    "Dhieec",
    "B\N{U+00e4}k\N{U+025b}l",
    "C\N{U+00e4}\N{U+014b}",
  ],
  day_stand_alone_narrow => [
    "J",
    "R",
    "D",
    "\N{U+014a}",
    "D",
    "B",
    "C",
  ],
  day_stand_alone_wide => [
    "Jiec la\N{U+0331}t",
    "R\N{U+025b}w l\N{U+00e4}tni",
    "Di\N{U+0254}\N{U+0331}k l\N{U+00e4}tni",
    "\N{U+014a}uaan l\N{U+00e4}tni",
    "Dhieec l\N{U+00e4}tni",
    "B\N{U+00e4}k\N{U+025b}l l\N{U+00e4}tni",
    "C\N{U+00e4}\N{U+014b} ku\N{U+0254}th",
  ],
  era_abbreviated => [
    "AY",
    "\N{U+0190}Y",
  ],
  era_narrow => [
    "AY",
    "\N{U+0190}Y",
  ],
  era_wide => [
    "A ka\N{U+0331}n Yecu ni dap",
    "\N{U+0190} ca Yecu dap",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Nuer",
  month_format_abbreviated => [
    "Tiop",
    "P\N{U+025b}t",
    "Du\N{U+0254}\N{U+0331}\N{U+0254}\N{U+0331}",
    "Guak",
    "Du\N{U+00e4}",
    "Kor",
    "Pay",
    "Thoo",
    "T\N{U+025b}\N{U+025b}",
    "Laa",
    "Kur",
    "Tid",
  ],
  month_format_narrow => [
    "T",
    "P",
    "D",
    "G",
    "D",
    "K",
    "P",
    "T",
    "T",
    "L",
    "K",
    "T",
  ],
  month_format_wide => [
    "Tiop thar p\N{U+025b}t",
    "P\N{U+025b}t",
    "Du\N{U+0254}\N{U+0331}\N{U+0254}\N{U+0331}\N{U+014b}",
    "Guak",
    "Du\N{U+00e4}t",
    "Kornyoot",
    "Pay yie\N{U+0331}tni",
    "Tho\N{U+0331}o\N{U+0331}r",
    "T\N{U+025b}\N{U+025b}r",
    "Laath",
    "Kur",
    "Tio\N{U+0331}p in di\N{U+0331}i\N{U+0331}t",
  ],
  month_stand_alone_abbreviated => [
    "Tiop",
    "P\N{U+025b}t",
    "Du\N{U+0254}\N{U+0331}\N{U+0254}\N{U+0331}",
    "Guak",
    "Du\N{U+00e4}",
    "Kor",
    "Pay",
    "Thoo",
    "T\N{U+025b}\N{U+025b}",
    "Laa",
    "Kur",
    "Tid",
  ],
  month_stand_alone_narrow => [
    "T",
    "P",
    "D",
    "G",
    "D",
    "K",
    "P",
    "T",
    "T",
    "L",
    "K",
    "T",
  ],
  month_stand_alone_wide => [
    "Tiop thar p\N{U+025b}t",
    "P\N{U+025b}t",
    "Du\N{U+0254}\N{U+0331}\N{U+0254}\N{U+0331}\N{U+014b}",
    "Guak",
    "Du\N{U+00e4}t",
    "Kornyoot",
    "Pay yie\N{U+0331}tni",
    "Tho\N{U+0331}o\N{U+0331}r",
    "T\N{U+025b}\N{U+025b}r",
    "Laath",
    "Kur",
    "Tio\N{U+0331}p in di\N{U+0331}i\N{U+0331}t",
  ],
  name => "Nuer South Sudan",
  native_language => "Thok Nath",
  native_name => "Thok Nath SS",
  native_script => undef,
  native_territory => "SS",
  native_variant => undef,
  quarter_format_abbreviated => [
    "P1",
    "P2",
    "P3",
    "P4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "P\N{U+00e4}th di\N{U+0254}k tin nhiam",
    "P\N{U+00e4}th di\N{U+0254}k tin guur\N{U+025b}",
    "P\N{U+00e4}th di\N{U+0254}k tin w\N{U+00e4} k\N{U+0254}\N{U+0254}ri\N{U+025b}n",
    "P\N{U+00e4}th di\N{U+0254}k tin ji\N{U+0254}akdi\N{U+025b}n",
  ],
  quarter_stand_alone_abbreviated => [
    "P1",
    "P2",
    "P3",
    "P4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "P\N{U+00e4}th di\N{U+0254}k tin nhiam",
    "P\N{U+00e4}th di\N{U+0254}k tin guur\N{U+025b}",
    "P\N{U+00e4}th di\N{U+0254}k tin w\N{U+00e4} k\N{U+0254}\N{U+0254}ri\N{U+025b}n",
    "P\N{U+00e4}th di\N{U+0254}k tin ji\N{U+0254}akdi\N{U+025b}n",
  ],
  script => undef,
  territory => "South Sudan",
  time_format_full => "zzzz h:mm:ss a",
  time_format_long => "z h:mm:ss a",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/nus-SS.pl <==
{
  am_pm_abbreviated => [
    "RW",
    "T\N{U+014a}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E\N{U+060c} d-M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E\N{U+060c} d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E\N{U+060c} d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "nus-SS",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jiec",
    "R\N{U+025b}w",
    "Di\N{U+0254}\N{U+0331}k",
    "\N{U+014a}uaan",
    "Dhieec",
    "B\N{U+00e4}k\N{U+025b}l",
    "C\N{U+00e4}\N{U+014b}",
  ],
  day_format_narrow => [
    "J",
    "R",
    "D",
    "\N{U+014a}",
    "D",
    "B",
    "C",
  ],
  day_format_wide => [
    "Jiec la\N{U+0331}t",
    "R\N{U+025b}w l\N{U+00e4}tni",
    "Di\N{U+0254}\N{U+0331}k l\N{U+00e4}tni",
    "\N{U+014a}uaan l\N{U+00e4}tni",
    "Dhieec l\N{U+00e4}tni",
    "B\N{U+00e4}k\N{U+025b}l l\N{U+00e4}tni",
    "C\N{U+00e4}\N{U+014b} ku\N{U+0254}th",
  ],
  day_stand_alone_abbreviated => [
    "Jiec",
    "R\N{U+025b}w",
    "Di\N{U+0254}\N{U+0331}k",
    "\N{U+014a}uaan",
    "Dhieec",
    "B\N{U+00e4}k\N{U+025b}l",
    "C\N{U+00e4}\N{U+014b}",
  ],
  day_stand_alone_narrow => [
    "J",
    "R",
    "D",
    "\N{U+014a}",
    "D",
    "B",
    "C",
  ],
  day_stand_alone_wide => [
    "Jiec la\N{U+0331}t",
    "R\N{U+025b}w l\N{U+00e4}tni",
    "Di\N{U+0254}\N{U+0331}k l\N{U+00e4}tni",
    "\N{U+014a}uaan l\N{U+00e4}tni",
    "Dhieec l\N{U+00e4}tni",
    "B\N{U+00e4}k\N{U+025b}l l\N{U+00e4}tni",
    "C\N{U+00e4}\N{U+014b} ku\N{U+0254}th",
  ],
  era_abbreviated => [
    "AY",
    "\N{U+0190}Y",
  ],
  era_narrow => [
    "AY",
    "\N{U+0190}Y",
  ],
  era_wide => [
    "A ka\N{U+0331}n Yecu ni dap",
    "\N{U+0190} ca Yecu dap",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Nuer",
  month_format_abbreviated => [
    "Tiop",
    "P\N{U+025b}t",
    "Du\N{U+0254}\N{U+0331}\N{U+0254}\N{U+0331}",
    "Guak",
    "Du\N{U+00e4}",
    "Kor",
    "Pay",
    "Thoo",
    "T\N{U+025b}\N{U+025b}",
    "Laa",
    "Kur",
    "Tid",
  ],
  month_format_narrow => [
    "T",
    "P",
    "D",
    "G",
    "D",
    "K",
    "P",
    "T",
    "T",
    "L",
    "K",
    "T",
  ],
  month_format_wide => [
    "Tiop thar p\N{U+025b}t",
    "P\N{U+025b}t",
    "Du\N{U+0254}\N{U+0331}\N{U+0254}\N{U+0331}\N{U+014b}",
    "Guak",
    "Du\N{U+00e4}t",
    "Kornyoot",
    "Pay yie\N{U+0331}tni",
    "Tho\N{U+0331}o\N{U+0331}r",
    "T\N{U+025b}\N{U+025b}r",
    "Laath",
    "Kur",
    "Tio\N{U+0331}p in di\N{U+0331}i\N{U+0331}t",
  ],
  month_stand_alone_abbreviated => [
    "Tiop",
    "P\N{U+025b}t",
    "Du\N{U+0254}\N{U+0331}\N{U+0254}\N{U+0331}",
    "Guak",
    "Du\N{U+00e4}",
    "Kor",
    "Pay",
    "Thoo",
    "T\N{U+025b}\N{U+025b}",
    "Laa",
    "Kur",
    "Tid",
  ],
  month_stand_alone_narrow => [
    "T",
    "P",
    "D",
    "G",
    "D",
    "K",
    "P",
    "T",
    "T",
    "L",
    "K",
    "T",
  ],
  month_stand_alone_wide => [
    "Tiop thar p\N{U+025b}t",
    "P\N{U+025b}t",
    "Du\N{U+0254}\N{U+0331}\N{U+0254}\N{U+0331}\N{U+014b}",
    "Guak",
    "Du\N{U+00e4}t",
    "Kornyoot",
    "Pay yie\N{U+0331}tni",
    "Tho\N{U+0331}o\N{U+0331}r",
    "T\N{U+025b}\N{U+025b}r",
    "Laath",
    "Kur",
    "Tio\N{U+0331}p in di\N{U+0331}i\N{U+0331}t",
  ],
  name => "Nuer South Sudan",
  native_language => "Thok Nath",
  native_name => "Thok Nath",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "P1",
    "P2",
    "P3",
    "P4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "P\N{U+00e4}th di\N{U+0254}k tin nhiam",
    "P\N{U+00e4}th di\N{U+0254}k tin guur\N{U+025b}",
    "P\N{U+00e4}th di\N{U+0254}k tin w\N{U+00e4} k\N{U+0254}\N{U+0254}ri\N{U+025b}n",
    "P\N{U+00e4}th di\N{U+0254}k tin ji\N{U+0254}akdi\N{U+025b}n",
  ],
  quarter_stand_alone_abbreviated => [
    "P1",
    "P2",
    "P3",
    "P4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "P\N{U+00e4}th di\N{U+0254}k tin nhiam",
    "P\N{U+00e4}th di\N{U+0254}k tin guur\N{U+025b}",
    "P\N{U+00e4}th di\N{U+0254}k tin w\N{U+00e4} k\N{U+0254}\N{U+0254}ri\N{U+025b}n",
    "P\N{U+00e4}th di\N{U+0254}k tin ji\N{U+0254}akdi\N{U+025b}n",
  ],
  script => undef,
  territory => "South Sudan",
  time_format_full => "zzzz h:mm:ss\N{U+202f}a",
  time_format_long => "z h:mm:ss\N{U+202f}a",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => "44.1",
}
